diff options
| author | zeertzjq <zeertzjq@outlook.com> | 2026-10-14 10:13:57 +0800 |
|---|---|---|
| committer | GitHub <noreply@github.com> | 2026-10-14 02:13:57 +0000 |
| commit | 655dc376a89ea9a8c34179c1f5176440ab55caed (patch) | |
| tree | 259efb2a20d6ea24ac5f91faccdbd2dbb279f119 /runtime/lua/vim/_ftplugin/lua.lua | |
| parent | f28a48e38bcbbc6ba2f9544eee1119b3fcc19bfb (diff) | |
| download | rneovim-655dc376a89ea9a8c34179c1f5176440ab55caed.tar.gz rneovim-655dc376a89ea9a8c34179c1f5176440ab55caed.tar.bz2 rneovim-655dc376a89ea9a8c34179c1f5176440ab55caed.zip | |
vim-patch:9.2.1182: autocommand checks paths for non-existing events (#42342)
Problem: has_autocmd() expands file names for events without
registered autocommands.
Solution: Return early when no autocommand patterns exist for the event
(Yasuhiro Matsumoto).
With my configuration on MS-Windows startup goes from 259 ms to 246 ms
(median of 9 runs).
closes: vim/vim#21449
https://github.com/vim/vim/commit/97a721d6c599829b242649d13844c4baa0f16b8a
Co-authored-by: Yasuhiro Matsumoto <mattn.jp@gmail.com>
Diffstat (limited to 'runtime/lua/vim/_ftplugin/lua.lua')
0 files changed, 0 insertions, 0 deletions